%%=============================================================================
%% sujet.cls
%% Copyright 2007-2023 Frédéric Goualard
%%                     Nantes Université, France.
%%
%% This program may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX 
%% version 1999/12/01 or later.
%%
%% This program consists of the files listed in manifest.txt
%%
%% Contributions (see ChangeLog).
%%=============================================================================


\def\sujet@version{2023/11/21, v. 4.7}

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{sujet}[\sujet@version]

%% Faut-il encadrer les champs pour les réponses ?
\newif\ifframedanswers
%% Cartouche avec le champs "nom" à remplir ?
\newif\ifwithname
\newif\ifisanonyme
\newif\ifcorrige

\corrigefalse
\isanonymefalse
\framedanswerstrue

\DeclareOption{12pt}{\PassOptionsToClass{12pt}{article}}
\DeclareOption{11pt}{\PassOptionsToClass{11pt}{article}}
\DeclareOption{TD}{\gdef\Type@Feuille{Feuille de travaux dirig\'es}}
\DeclareOption{EXAMEN}{\gdef\Type@Feuille{Examen}\gdef\type@f{EXAMEN}}
\DeclareOption{EXAMENTP}{\gdef\Type@Feuille{Examen de travaux pratiques}}
\DeclareOption{EXAMEN1}{\gdef\Type@Feuille{Examen --- 1\iere{} session}}
\DeclareOption{EXAMEN2}{\gdef\Type@Feuille{Examen --- 2\ieme{} session}}
\DeclareOption{TP}{\gdef\Type@Feuille{Feuille de travaux pratiques}}
\DeclareOption{CC}{\gdef\Type@Feuille{Contr\^ole continu}}
\DeclareOption{CCTP}{\gdef\Type@Feuille{Contr\^ole continu de travaux pratiques}}
\DeclareOption{CCTD}{\gdef\Type@Feuille{\'Evaluation continue de travaux dirig\'es}%
	\global\withnametrue}
\DeclareOption{AUTRE}{\gdef\Type@Feuille{\@TypeFeuillePerso}} 
\DeclareOption{anonyme}{\global\isanonymetrue}
\DeclareOption{cartouchenom}{\global\withnametrue}
\DeclareOption{corrige}{\global\corrigetrue}

\ExecuteOptions{a4paper,10pt,oneside,onecolumn,final,TD}
\ProcessOptions\relax
\LoadClass[a4paper]{article}

\RequirePackage{lastpage}
\RequirePackage[svgnames]{xcolor}
\definecolor{shadecolor}{rgb}{1,1,1}
%% Fontes utilisées
\RequirePackage{libertine}
\RequirePackage{inconsolata}
\RequirePackage[T1]{fontenc}

\RequirePackage{fancyhdr}
\pagestyle{fancy}
\RequirePackage{verbatim}
\RequirePackage{mdframed}
\RequirePackage{xparse}


\renewcommand{\maketitle}{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
		  \@maketitle
    \thispagestyle{fancy}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
}

\def\@groupe{}
\newcommand{\groupe}[1]{\gdef\@groupe{#1}}
\def\@surname{}
\newcommand{\surname}[1]{\gdef\@surname{#1}}
\def\@givenname{}
\newcommand{\givenname}[1]{\gdef\@givenname{#1}}

\providecommand{\no}{n$^\circ$}

\def\CORRECTION{CORRECTION}
\def\surnametext{Nom(s)}
\def\givennametext{Pr\'enom(s)}
\def\groupnametext{Groupe}
\def\@maketitle{%
  \lhead{}
  \chead{}
  \rhead{}
  \lfoot{{\tiny\@intitule\ --- Nantes Universit\'e}}
  \cfoot{{\tiny\Type@Feuille 
	\ifnum\value{num@TD}<0%
		\relax
	\else% 
      	\ \no{}\number\value{num@TD}%
	\fi%
	\ifx\@foottitle\@empty\else~--- \@foottitle\fi}}
  \rfoot{{\tiny\thepage/\pageref{LastPage}}}

  \newpage
  \null
  {\large\@cursus \hfill Nantes Universit\'e}\par{\parindent 0pt
  {\large\@intitule \hfill \ifx\annee@scolaire@user\@empty\annee@scolaire\else\annee@scolaire@user\fi}}
  \vskip 2em
  \ifwithname\noindent%
	\begin{mdframed}[backgroundcolor=shadecolor]
	 \noindent \surnametext: \hbox to 5cm{\@surname} \givennametext: \hbox to 4.2cm{\@givenname} \groupnametext: \hbox to .8cm{\@groupe}
	\end{mdframed}

  \fi%
  \begin{center}%
    \let \footnote \thanks
    \ifcorrige{\fontsize{23pt}{15pt}\selectfont\bfseries\color{red}\CORRECTION}\\\fi
    {\LARGE\emph{\Type@Feuille}\ %
	 \ifnum\value{num@TD}<0 
		\relax
	 \else
		\no{}\number\value{num@TD}
	 \fi\par}
    {\LARGE\sf \@title \par}%
    \bigskip
    \vskip 1.5em%
    {\large \@date}%
  \end{center}%
  \par
  \vskip 1.5em}


\def\@TypeFeuillePerso{\ClassError{sujet}{pas de type utilisateur défini}{Utilisez la macro \string\TypeUtilisateur\space pour définir votre type de feuille.}}

\newcommand{\TypeUtilisateur}[1]{\gdef\@TypeFeuillePerso{#1}}

\newcounter{num@TD}
\setcounter{num@TD}{-1}
\def\Numero@Feuille#1{\setcounter{num@TD}{#1}}

\newcommand{\cursus}[1]{\gdef\@cursus{{\parindent 0pt #1}}}
\newcommand{\intitule}[1]{\gdef\@intitule{#1}}

\let\annee@scolaire@user\@empty
\newcommand{\annee}[1]{\gdef\annee@scolaire@user{#1}}
\def\annee@scolaire{\ifnum\number\month<8{\advance\year by -1 \number\year/%
    \advance\year by 1 \number\year}%
  \else%
  {\number\year/\advance\year by 1 \number\year}\fi}

% Environnement exercice.
\newcounter{exercice}
\setcounter{exercice}{0}
\def\theexercice{\ifnum\value{num@TD}>0 \arabic{num@TD}.\fi%
  \arabic{exercice}}
\def\exercisename{Exercice}
\def\exercicename{} %% Still accepted for backward compatibility
\newsavebox{\tmp@Exo}
\newlength{\page@size}
\newenvironment{exercice}[1][]{%
   \setlength{\page@size}{\hsize}\addtolength{\page@size}{-.6em}\par\bigskip%
   \parindent 0pt
   \refstepcounter{exercice}
   {\bfseries%
      \if\@obligatoire o \gdef\@obligatoire{n} \hspace*{-9pt}
      {\large$^\star$}\fi%
      \ifx\exercicename\@empty\exercisename\else\exercicename\fi\ \theexercice%
      \def\@tempa{#1}
      \ifx\@tempa\@empty\expandafter\gdef\csname nb\alph{exercice}\endcsname{}%
      \else~(#1)\expandafter\gdef\csname nb\alph{exercice}\endcsname{~(#1)}%
      \fi}\par\smallskip}%
  {}

  \def\begin@framed{\ifframedanswers\begin{mdframed}[linewidth=1pt]%
        \else\begin{mdframed}[linewidth=0pt]\fi}
\def\end@framed{\end{mdframed}}

\newcommand{\unecorrection}[1][?]{%
	\begin{mdframed}[fontcolor=red,font=\sffamily,backgroundcolor=shadecolor,linewidth=1pt]
 	\textbf{\raisebox{1pt}{$\bigtriangledown\:$}Correction\hrulefill}\par
	}
\def\endunecorrection{%
	\end{mdframed}
	\medskip
}

\gdef\anonname{Num\'ero d'anonymat}

\ifisanonyme
\RequirePackage{bophook}
\def\set@AnonCartouche{%
	\setlength{\unitlength}{1cm}
	\put(8,-1.5){%
		\begin{minipage}{5cm}%
		  \begin{mdframed}[backgroundcolor=shadecolor,linewidth=1pt]
			\begin{center}
        \bfseries\large \anonname\\[15pt]
        \vfill\null
			\end{center}
         \end{mdframed}
		\end{minipage}
  }
}
\newcommand{\setAnonCartouche}{\AtBeginPage{\set@AnonCartouche}}
\AtBeginPage{\ifnum\value{page}=1%
  \set@AnonCartouche
\fi}
\fi

\newcommand{\reponse@interne}[1]{%
  \ifcorrige\else
  \begin@framed
    \hbox to \textwidth{}\vspace*{#1}
\end@framed
\fi}

\NewDocumentEnvironment{@commentaire}{ o }{%
  \comment
}{%
  \endcomment
  \IfNoValueF{#1}{\reponse@interne{#1}}
}

\ifcorrige
  \let\correction=\unecorrection
  \let\endcorrection=\endunecorrection
  \def\reponse#1{\textcolor{red}{#1}}
\else
  \let\correction=\@commentaire
  \let\endcorrection=\end@commentaire
  \def\reponse#1{}
\fi 

\newcommand{\code}[1]{\textcolor{black}{\texttt{#1}}}

\def\cleardoublepage{\clearpage\thispagestyle{empty}%
  \ifodd\c@page\else
    \hbox{}\newpage\thispagestyle{empty}\if@twocolumn\hbox{}\newpage\fi\fi}

\renewcommand{\footrulewidth}{.4pt}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\headwidth}{\hsize}

\def\lastpage@feuille@putlabel{\addtocounter{page}{-1}%
   \immediate\write\@auxout{\string
   \newlabel{last@page@feuille}{{}{\thepage}}{}{}{}}%
   \addtocounter{page}{1}}

\newenvironment{feuille}[1][-1]{%
  \Numero@Feuille{#1}%
  \maketitle}{\clearpage}%\lastpage@feuille@putlabel}

\def\@obligatoire{n}
\newcommand{\obligatoire}{\gdef\@obligatoire{o}}

\let\@foottitle\@empty
\def\title#1{\gdef\@title{#1}\ifx\@foottitle\@empty\gdef\@foottitle{#1}\fi}
\def\foottitle#1{\gdef\@foottitle{#1}}

\RequirePackage{hyperref}
\hypersetup{colorlinks=true,linkcolor=[rgb]{0,0.4,0.8},urlcolor=[rgb]{0,0.4,0.8},pdfpagelabels}
%% Load geometry *after* hyperref
\RequirePackage{geometry}
\geometry{a4paper,textheight=24cm,textwidth=16cm}

\endinput

%%% Local Variables: 
%%% mode: latex
%%% TeX-master: t
%%% End: 
